Module blaxel.models.store_function
===================================

Classes
-------

`StoreFunction(created_at: blaxel.types.Unset | str = <blaxel.types.Unset object>, updated_at: blaxel.types.Unset | str = <blaxel.types.Unset object>, created_by: blaxel.types.Unset | str = <blaxel.types.Unset object>, updated_by: blaxel.types.Unset | str = <blaxel.types.Unset object>, configuration: blaxel.types.Unset | list['StoreConfiguration'] = <blaxel.types.Unset object>, description: blaxel.types.Unset | str = <blaxel.types.Unset object>, display_name: blaxel.types.Unset | str = <blaxel.types.Unset object>, image: blaxel.types.Unset | str = <blaxel.types.Unset object>, kit: blaxel.types.Unset | list['StoreFunctionKit'] = <blaxel.types.Unset object>, labels: blaxel.types.Unset | ForwardRef('StoreFunctionLabels') = <blaxel.types.Unset object>, name: blaxel.types.Unset | str = <blaxel.types.Unset object>, parameters: blaxel.types.Unset | list['StoreFunctionParameter'] = <blaxel.types.Unset object>)`
:   Store function
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        created_by (Union[Unset, str]): The user or service account who created the resource
        updated_by (Union[Unset, str]): The user or service account who updated the resource
        configuration (Union[Unset, list['StoreConfiguration']]): Store function configuration
        description (Union[Unset, str]): Store function description
        display_name (Union[Unset, str]): Store function display name
        image (Union[Unset, str]): Store function image
        kit (Union[Unset, list['StoreFunctionKit']]): Store function kit
        labels (Union[Unset, StoreFunctionLabels]): Store function labels
        name (Union[Unset, str]): Store function name
        parameters (Union[Unset, list['StoreFunctionParameter']]): Store function parameters
    
    Method generated by attrs for class StoreFunction.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `configuration`
    :

    `created_at`
    :

    `created_by`
    :

    `description`
    :

    `display_name`
    :

    `image`
    :

    `kit`
    :

    `labels`
    :

    `name`
    :

    `parameters`
    :

    `updated_at`
    :

    `updated_by`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :